.. _basic_modules:

=======
Basics
=======

**Contents**

.. toctree::
    :maxdepth: 2

    ../../../modules/assumptions/index.rst
    ../../../modules/calculus/index.rst
    ../../../modules/combinatorics/index.rst
    ../../../modules/functions/index.rst
    ../../../modules/integrals/index.rst
    ../../../modules/series/index.rst
    ../../../modules/simplify/index.rst
    ../../../modules/solvers/index.rst
    ../../../modules/abc.rst
    ../../../modules/algebras.rst
    ../../../modules/concrete.rst
    ../../../modules/core.rst
    ../../../modules/discrete.rst
    ../../../modules/evalf.rst
    ../../../modules/numeric-computation.rst
    ../../../modules/rewriting.rst
